//*****************************************************************************
//*****************************************************************************
//  FILENAME:  `@LIB_NAME`_VarFreqPWM.c
//  Version: 1.1, Updated on 2007/04/20 at 14:00:01 
//  Application: PSoC Express 2.0
//
//  DESCRIPTION:  This Driver controls the Variable Frequency PWM parameters
//				  and returns the period and percent duty cycle for the
//				  selected channel.
//-----------------------------------------------------------------------------
//      Copyright (c) Cypress MicroSystems 2004-2006. All Rights Reserved.
//*****************************************************************************
//*****************************************************************************

#include "m8c.h"
#include "`@LIB_NAME`_VarFreqPWM.h"
#include "cmx.h"

// Channel type header file
#include "cmx_pwmvfreq_chan.h"

//-----------------------------------------------------------------------------
//  FUNCTION NAME: VarFreqPWM_Instantiate(const `@LIB_NAME`_VarFreqPWM_ParameterBlock * thisBLK)
//
//  DESCRIPTION: 
//     VarFreqPWM Initialization
//
//-----------------------------------------------------------------------------
//
//  ARGUMENTS: 
//     thisBLK => Pointer to parameter Block for this instance.
//
//  RETURNS: None
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE: Initialization for VarFreqPWM
//     Initial conditions set based on parameters set in
//     VarFreqPWM Parameter block
//-----------------------------------------------------------------------------
void `@LIB_NAME`_VarFreqPWM_Instantiate(const `@LIB_NAME`_VarFreqPWM_ParameterBlock * thisBLK)
{
    BYTE bInstance;
    BYTE Polarity;
    BYTE bPeriod;

    bInstance = thisBLK->VarFreqPWM_ChannelID;
    Polarity = thisBLK->VarFreqPWM_Polarity;

    PWMVFreqSetPolarity(bInstance,Polarity);

	bPeriod = PWMVFreqGetInitialPeriod(bInstance);
    
	PWMVFreqSetPeriod(bInstance, 100);
    PWMVFreqSetDutyCycle(bInstance, 0, bPeriod);
    PWMVFreqStart(bInstance);
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME: VarFreqPWM_SetValue(const `@LIB_NAME`_VarFreqPWM_ParameterBlock * thisBLK, BYTE bPercentFreqChange)
//
//  DESCRIPTION: 
//     Sets the current PWM frequency based on the Base Frequency percent value
//	   given as a parameter.
//
//-----------------------------------------------------------------------------
//
//  ARGUMENTS:  
//     thisBLK            => Pointer to parameter Block for this instance.
//     bPercentFreqChange => Percentage of Base Frequncy to set.
//
//  RETURNS: None
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE:
//     Controls the output PWM signal frequency by setting the appropriate
//	   period value and duty cycle value according to the Base Frequency
//	   percentage given for the current instance.
//-----------------------------------------------------------------------------

void `@LIB_NAME`_VarFreqPWM_SetValue(const `@LIB_NAME`_VarFreqPWM_ParameterBlock * thisBLK, BYTE bPercentFreqChange)
{
    BYTE bInstance;
    BYTE bPeriod;
	
	bInstance = thisBLK->VarFreqPWM_ChannelID;
	
	if(bPercentFreqChange<50) bPercentFreqChange=50;
	if(bPercentFreqChange>200) bPercentFreqChange=200;
	
	bPeriod = PWMVFreqGetInitialPeriod(bInstance);
	
	bPeriod = ((int)bPeriod * 100) / (int)bPercentFreqChange;
   
	PWMVFreqSetPeriod(bInstance, bPeriod);
    PWMVFreqSetDutyCycle(bInstance, thisBLK->VarFreqPWM_DutyCycle, bPeriod);
}
