;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: cmx_pwmvfreq_chan.asm
;;   @Version@
;;  
;;
;;  DESCRIPTION: Implements pwmVFreq channel interface
;; 
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2004-2006. All Rights Reserved.
;;*****************************************************************************
;;  HISTORY:
;;
;;*****************************************************************************
include "m8c.inc"
include "memory.inc"
include "psocapi.inc"
include "DriverDecl.inc"

;-----------------------------------------------
;  Interface Functions
;-----------------------------------------------
 
export  _PWMVFreqStart
export   PWMVFreqStart

export  _PWMVFreqSetPulseWidth
export   PWMVFreqSetPulseWidth

export  _PWMVFreqGetInitialPeriod
export   PWMVFreqGetInitialPeriod

export  PWMVFreqSetPeriod
export  _PWMVFreqSetPeriod

export  _PWMVFreqSetPolarity
export   PWMVFreqSetPolarity

export  _PWMVFreqSuspend
export   PWMVFreqSuspend

export  _PWMVFreqChannelPins
export   PWMVFreqChannelPins 

export  _PWMVFreqChannelBlocks
export   PWMVFreqChannelBlocks

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------

area text(ROM,REL)
.literal
_PWMVFreqChannelPins:
 PWMVFreqChannelPins:
    db 16h

_PWMVFreqChannelBlocks:
 PWMVFreqChannelBlocks:
	db 01h
.endliteral
;-----------------------------------------------
 
 
area    text(ROM,REL)
-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqStart
;
;  DESCRIPTION: 
;    This function starts the selected PWMVFreq.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: Channel ID of selected PWMVFreq in A
;
;  RETURNS: Nothing
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
	
 PWMVFreqStart:
_PWMVFreqStart:

    asl   A
    asl   A
    jacc  PWMVFreqStrt_JTable ; @STEP_SIZE=4 @NUM_STEPS=1

PWMVFreqStrt_JTable:
	; Start PWMVFREQ_01
	nop
    ljmp  PWMVFREQ_01_Start ; call UM API

;-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqSetPulseWidth
;
;  DESCRIPTION: 
;    This function writes the compare value of the selected pwmVFreq.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: Channel ID of selected pwmVFreq in A and pulse width in X
;
;  RETURNS: Nothing
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
 PWMVFreqSetPulseWidth:
_PWMVFreqSetPulseWidth:
 
    asl   A
    asl   A
    jacc  SetPW_JTable ; @STEP_SIZE=4 @NUM_STEPS=1

SetPW_JTable:
	; Set PulseWidth for PWMVFREQ_01
    mov   A,X ; move pulsewidth byte to A
    ljmp  PWMVFREQ_01_WritePulseWidth ; call UM API

;-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqGetPeriod
;
;  DESCRIPTION: 
;    This function returns the period value of the selected pwmVFreq.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: 
;    A => Channel ID
;
;  RETURNS: 
;    Period value in A
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
 PWMVFreqGetInitialPeriod:
_PWMVFreqGetInitialPeriod:
 
    asl   A
    asl   A
    jacc  GetPer_JTable ; @STEP_SIZE=4 @NUM_STEPS=1
	
GetPer_JTable:
	; Get Period for PWMVFREQ_01
    mov   A,124 ; 2 bytes, move period byte to A								
    ret ; 1 byte
    nop ; 1 byte, 4 total for section
	

;-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqSetPeriod
;
;  DESCRIPTION: 
;    This function writes the period value of the selected pwmVFreq.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: Channel ID of selected pwmVFreq in A and period width in X
;
;  RETURNS: Nothing
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
 PWMVFreqSetPeriod:
_PWMVFreqSetPeriod:
 
    asl   A
    asl   A
    jacc  SetPeriod_JTable ; @STEP_SIZE=4 @NUM_STEPS=1

SetPeriod_JTable:
	; Set Period for PWMVFREQ_01
    mov   A,X ; move period byte to A
    ljmp  PWMVFREQ_01_WritePeriod ; call UM API



-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqSetPolarity
;
;  DESCRIPTION: 
;    Programs positive polarity or negative polarity through reg
;    RDIxLTx.
; 
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: 
;    A => Channel ID 
;    X => polarity
;
;  RETURNS: nothing
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;

 PWMVFreqSetPolarity:
_PWMVFreqSetPolarity:
	push A
	mov  A,X ; zero if neg polarity, nonzero if positive           
    jnz positive
negative:
	pop  A
	asl  A ; x2
	asl  A ; x4
	asl  A ; x8
	jacc PWMVFreqPol_Neg_JTable ; @STEP_SIZE=8 @NUM_STEPS=1
PWMVFreqPol_Neg_JTable:
	; Set LUT polarity for PWMVFREQ_01  
	and  reg[B4h], ~0Fh ; 3 byte instruction
	or   reg[B4h], (CCh & 0Fh) ; 3 byte instruction
	nop	; 1 byte instruction
	ret	; 1 byte instruction

positive:
	pop  A
	asl  A ; x2
	asl  A ; x4
	asl  A ; x8
	jacc PWMVFreqPol_Pos_JTable ; @STEP_SIZE=8 @NUM_STEPS=1
PWMVFreqPol_Pos_JTable:  
	; Set LUT polarity for PWMVFREQ_01  
	and  reg[B4h], ~0Fh ; 3 byte instruction
	or   reg[B4h], (33h & 0Fh) ; 3 byte instruction
	nop	; 1 byte instruction
	ret	; 1 byte instruction

-----------------------------------------------------------------------------
;  FUNCTION NAME: PWMVFreqSuspend
;
;  DESCRIPTION: 
;    Forces high or low state at the row output lut through reg
;    RDIxLTx.
; 
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: 
;    A => channel ID 
;    X => polarity of channel, 1 for high or 0 for low
;
;  RETURNS: none
;
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;

 PWMVFreqSuspend:
_PWMVFreqSuspend:
	push A
	mov  A,X ; zero if low, nonzero if high           
    jnz high
low:
	pop  A
	asl  A ; x2
	asl  A ; x4
	asl  A ; x8
	jacc PWMVFreqSuspend_Neg_JTable ; @STEP_SIZE=8 @NUM_STEPS=1
PWMVFreqSuspend_Neg_JTable:
	; Set LUT to 0 for PWMVFREQ_01  
	and  reg[B4h], ~0Fh ; 3 byte instruction
	or   reg[B4h], (00h & 0Fh) ; 3 byte instruction
	nop	; 1 byte instruction
	ret	; 1 byte instruction

high:
	pop  A
	asl  A ; x2
	asl  A ; x4
	asl  A ; x8
	jacc PWMVFreqSuspend_Pos_JTable ; @STEP_SIZE=8 @NUM_STEPS=1
PWMVFreqSuspend_Pos_JTable:  
	; Set LUT to 1 for PWMVFREQ_01  
	and  reg[B4h], ~0Fh ; 3 byte instruction
	or   reg[B4h], (FFh & 0Fh) ; 3 byte instruction
	nop	; 1 byte instruction
	ret	; 1 byte instruction


 



