//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>          // part specific constants and macros
#include "PSoCAPI.h"      // PSoC API definitions for all User Modules

#include "driverdecl.h"
#include "CMXSystem.h"
#include "CMXSystemExtern.h"
#include "TransferFunction.h"

#include "cmx.h"
#include "ProjectProperties.h"
#include "Custom.h"

// Channel includes
// ADC_00 Include
#include "CMX_ADC_CHAN.h"

void main()
{
    // Initialize Project
    M8C_EnableGInt;                            // Turn on interrupts 
    I2C_CFG &= 0xFC;                           // Disable I2C in case it's not used.
    SystemTimer_Start();
    SystemTimer_SetInterval(SystemTimer_64_HZ);
    SystemTimer_EnableInt();

    // Initialize Channels
    // ADC_00 Initialization  
    AdcScanReset(); // Initialize ADC scanner
    ADC10_Start(ADC10_FULLRANGE);     // Start the User Module  
    ADC10_iCal(0x1FF, ADC10_CAL_VBG);  // Calibrate the ADC so 1.3V = 0x01FF  
    bADC_Mode = 1;  // Turn scanning on after calibration
    ADC10_StartADC();

    // Initialize Variables
	SystemVars.ReadOnlyVars.pse_Buzzer = 100;
	SystemVars.ReadOnlyVars.pse_LED_GREEN = 2;
	SystemVars.ReadOnlyVars.pse_LightSensor = 0;

    // Driver instantiations
CMX_BLINKINGLED_Instantiate(&pse_LED_GREEN);
CMX_BLINKINGLED_SetValue(&pse_LED_GREEN, (BYTE)SystemVars.ReadOnlyVars.pse_LED_GREEN);
// Not require for ID_pse_LightSensor
CMX_VarFreqPWM_Instantiate(&pse_Buzzer);

    // Custom initization code.
    CustomInit();
    // End Initialize Project

	while(1)
	{
        // Sync loop sample rate
#if ( SAMPLE_DIVIDER  )
        SystemTimer_SyncWait(SAMPLE_DIVIDER, SystemTimer_WAIT_RELOAD);
#endif

		// update input variables
		SystemVars.ReadOnlyVars.pse_LightSensor = CMX_LX1972L_GetValue(&pse_LightSensor);

        // Custom Post Input function
        CustomPostInputUpdate();

		// run transfer function and update output variables
		TransferFunction();

        // CustomPreOutputUpdate();
        CustomPreOutputUpdate();

		// set outputs
		CMX_VarFreqPWM_SetValue(&pse_Buzzer, (BYTE)SystemVars.ReadOnlyVars.pse_Buzzer);
		CMX_BLINKINGLED_SetValue(&pse_LED_GREEN, (BYTE)SystemVars.ReadOnlyVars.pse_LED_GREEN);

	}
}
